#
# spec file for package python-sphinxext-opengraph
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-sphinxext-opengraph
Version:        0.9.1
Release:        1.5
Summary:        Sphinx Extension to enable OGP support
License:        MIT
URL:            https://github.com/wpilibsuite/sphinxext-opengraph
Source:         https://files.pythonhosted.org/packages/source/s/sphinxext-opengraph/sphinxext-opengraph-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python3-Sphinx >= 2.0
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Sphinx >= 2.0}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sphinxext-opengraph}
%endif
%python_subpackages

%description
Sphinx Extension to enable OGP support

%prep
%setup -q -n sphinxext-opengraph-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE.md
%dir %{python_sitelib}/sphinxext
%{python_sitelib}/sphinxext/opengraph
%{python_sitelib}/sphinxext_opengraph-%{version}.dist-info
%endif

%changelog
* Mon Dec 18 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.1:
  * Test Sphinx 7
  * Fix default Roboto font not being found by the matplotlib
    FontManager
- update to 0.9.0:
  * make matplotlib optional
  * Drop EOL Python 3.7, Bump PyPy to 3.9
- update to 0.8.2:
  * Fix DeprecationWarning: The 'warn' method is deprecated, use
    'warning' instead
  * FIX: Social media twitter card tags
- update to 0.8.1:
  * Add exception for SVG images
- update to V0.8.0:
  * Format with Black 23.1.0
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to v0.7.5:
  * check for description length before subscripting
  * Use Sphinx Builder method to get page url
  * Fix field names in readme
  * Allow dirhtml builder without ogp_site_url
  * Take default og:site_name from sphinx project config value
  * Do not append index with dirhtml
  * Create wheel with version number not "main"
  * Don't run CI on tag and push
  * Fix option name in README.md.
  * Test multiple Sphinx and OS versions
  * Fix ci workflow syntax
  * Tidy up whitespace
  * ci: Pin PyPI publish action to v1
  * Add support for meta description
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.6.3
  Fix first_image not resolving correctly when in subdirectories and ogp_image is defined. by @ItayZiv in #63
- Update to version 0.6.2
  chore(README) Typo fix by @tony in #58
  Fix first_image not resolving correctly in subdirectories by @ItayZiv in #61
- Update to version 0.6.1
  fix og:url for "dirhtml" builder by @ru-fu in #54
- Update to version 0.6.0
  Include license in setup.py by @sciencewhiz in #52
  Add per-file overrides using field lists by @ItayZiv in #50
- Update to version 0.5.1
  Escape quotations in Open Graph description when smart quotes are disabled. by @ItayZiv in #49
- Update to version 0.5.0
  Skipping code blocks and fixing docs build. by @Robpol86 in #47
  Convert relative paths to absolute in og:image. by @Robpol86 in #48
* Fri Sep 17 2021 Matej Cepl <mcepl@suse.com>
- Limit ownership of packages in sitelib.
* Thu Sep 16 2021 Enrico Belleri <idesmi@protonmail.com>
- initial package
